@@ -19,14 +19,13 @@
 
 from __future__ import unicode_literals
 
-from datetime import datetime
 import json
 import os
 
 from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.http import Http404
-from django.test import Client, TestCase
+from django.test import Client, TestCase, TransactionTestCase
 from django.test.utils import override_settings
 from mock import MagicMock, Mock, patch
 
@@ -34,7 +33,6 @@ import wirecloud.catalogue.utils
 from wirecloud.catalogue.models import CatalogueResource
 from wirecloud.catalogue.utils import get_resource_data
 from wirecloud.catalogue.views import serve_catalogue_media
-from wirecloud.commons.searchers import get_search_engine
 from wirecloud.commons.utils.testcases import uses_extra_resources, WirecloudTestCase
 
 
@@ -42,11 +40,13 @@ from wirecloud.commons.utils.testcases import uses_extra_resources, WirecloudTes
 __test__ = False
 
 
-class CatalogueSearchTestCase(WirecloudTestCase):
+class CatalogueSearchTestCase(WirecloudTestCase, TestCase):
+
+    # TODO this API should be moved to /api/search
 
     fixtures = ('catalogue_search_data',)
+    tags = ('wirecloud-catalogue', 'wirecloud-catalogue-search', 'wirecloud-noselenium', 'wirecloud-catalogue-noselenium', 'wirecloud-search-api')
     populate = False
-    tags = ('wirecloud-catalogue', 'wirecloud-catalogue-search', 'wirecloud-noselenium', 'wirecloud-catalogue-noselenium')
 
     WIRECLOUD_RESULTS = {'Wirecloud/TestOperator/2.0', 'Wirecloud/test-mashup/1.0.5', 'Wirecloud/Book-Reader/1.5', 'Wirecloud/Test/2.5', 'CoNWeT-Lab/Clock_Now/1.11'}
     MASHABLE_RESULTS = {'Wirecloud/test-mashup/1.0', 'Wirecloud/Test/2.5', 'CoNWeT/test-mashup-dependencies/1.5.5'}
@@ -186,26 +186,51 @@ class CatalogueSearchTestCase(WirecloudTestCase):
         response = self.client.get(self.base_url + '?staff=true&pagenum=5&maxresults=5')
         self.check_last_page(response)
 
+    def test_search_field_collapsing(self):
+        self.client.login(username='admin', password='admin')
+
+        # Less hits than the maxresults parameter
+        response = self.client.get(self.base_url + '?q=test&staff=true&maxresults=15')
+        self.assertEqual(response.status_code, 200)
+        result_json = json.loads(response.content.decode('utf-8'))
+        self.assertEqual(result_json['pagenum'], 1)
+        self.assertEqual(result_json['pagecount'], 1)
+        self.assertEqual(result_json['pagelen'], len(result_json['results']))
+        self.assertEqual(result_json['pagelen'], 6)
+        self.assertEqual(result_json['total'], result_json['pagelen'])
+        n = result_json['pagelen'] + sum([len(i['others']) for i in result_json['results']])
+        self.assertEqual(n, 11)
+
     def test_basic_search_with_querytext(self):
 
         self.client.login(username='myuser', password='admin')
 
+        # keywords terms and mashable are in the description of the
+        # Wirecloud/Test/1.5 widget
         result = self.client.get(self.base_url + '?q=term+mashable')
         result_json = json.loads(result.content.decode('utf-8'))
         self.assertEqual(result.status_code, 200)
         self.assertEqual(result_json['pagelen'], 1)
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
         self.assertEqual(result_json['results'][0]['version'], "1.5")
-        self.assertEqual(len(result_json['results'][0]['others']), 2)
+        self.assertEqual(len(result_json['results'][0]['others']), 0)
 
+        # keywords mashable and application are in the description of the
+        # Wirecloud/Test/{1.5,2.0,2.5} widgets and the Wirecloud/test-mashup/1.0
+        # mashup
         result = self.client.get(self.base_url + '?q=mashable+application')
         result_json = json.loads(result.content.decode('utf-8'))
         self.assertEqual(result.status_code, 200)
         self.assertEqual(result_json['pagelen'], 2)
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
         self.assertEqual(result_json['results'][0]['version'], "1.0")
-        self.assertEqual(len(result_json['results'][0]['others']), 1)
+        self.assertEqual(len(result_json['results'][0]['others']), 0)
+        self.assertEqual(result_json['results'][1]['version'], "2.5")
+        self.assertEqual(len(result_json['results'][1]['others']), 2)
 
+        # keyword mashable is present in the description of the
+        # Wirecloud/Test/{1.5,2.0,2.5} widgets and the Wirecloud/test-mashup/1.0
+        # and the Wirecloud/test-mashup-dependencies/1.5.5 mashups
         result = self.client.get(self.base_url + '?q=mashable')
         result_json = json.loads(result.content.decode('utf-8'))
         self.assertEqual(result.status_code, 200)
@@ -214,26 +239,35 @@ class CatalogueSearchTestCase(WirecloudTestCase):
         self.assertEqual(result_json['results'][0]['version'], "1.5.5")
         self.assertEqual(len(result_json['results'][0]['others']), 0)
         self.assertEqual(result_json['results'][1]['version'], "1.0")
-        self.assertEqual(len(result_json['results'][1]['others']), 1)
+        self.assertEqual(len(result_json['results'][1]['others']), 0)
+        self.assertEqual(result_json['results'][2]['version'], "2.5")
+        self.assertEqual(len(result_json['results'][2]['others']), 2)
 
+        # keywords output and digit are present in the description of the
+        # Wirecloud/Test/1.5 widget (inside the description of the
+        # outputendpoint endpoint)
         result = self.client.get(self.base_url + '?q=output+digit')
         result_json = json.loads(result.content.decode('utf-8'))
         self.assertEqual(result.status_code, 200)
         self.assertEqual(result_json['pagelen'], 1)
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
         self.assertEqual(result_json['results'][0]['version'], "1.5")
-        self.assertEqual(len(result_json['results'][0]['others']), 2)
+        self.assertEqual(len(result_json['results'][0]['others']), 0)
 
+        # Switch session user to MyUser
         self.client.logout()
         self.client.login(username='MyUser', password='admin')
 
+        # keywords test, mashup and dependencies are present in the description
+        # of the Wirecloud/test-mashup-dependencies/{1.5.5,1.10.5} mashups, but
+        # MyUser only has access to Wirecloud/test-mashup-dependencies/1.10.5
         result = self.client.get(self.base_url + '?q=test+mashup+dependencies')
         result_json = json.loads(result.content.decode('utf-8'))
         self.assertEqual(result.status_code, 200)
         self.assertEqual(result_json['pagelen'], 1)
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
         self.assertEqual(result_json['results'][0]['version'], "1.10.5")
-        self.assertEqual(len(result_json['results'][0]['others']), 1)
+        self.assertEqual(len(result_json['results'][0]['others']), 0)
 
     def test_basic_search_with_querytext_empty(self):
 
@@ -247,42 +281,6 @@ class CatalogueSearchTestCase(WirecloudTestCase):
         self.assertEqual(result_json['pagelen'], 0)
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
 
-    def test_basic_search_with_querytext_multireader_empty(self):
-
-        # Check WireCloud is not affected by bug #415 of Whoosh
-        # Force whoosh to use a MultiReader instance
-        searcher = get_search_engine('resource')
-        with searcher.get_batch_writer() as writer:
-            writer.add_document(**{
-                'pk': '1000',
-                'vendor_name': 'Wirecloud/new',
-                'vendor': 'Wirecloud',
-                'name': 'new',
-                'version': '1.0',
-                'template_uri': 'http://example.com',
-                'type': 'widget',
-                'creation_date': datetime.utcnow(),
-                'public': False,
-                'title': 'New',
-                'description': 'description',
-                'wiring': 'description',
-                'image': 'image.png',
-                'smartphoneimage': 'smartphoneimage.png',
-                'users': '',
-                'groups': '',
-                'content': 'detailed description',
-            })
-
-        self.client.login(username='myuser', password='admin')
-
-        # Empty query
-        result = self.client.get(self.base_url + '?q=totally+uncorrectable+search+giving+an+empty+resultset')
-        result_json = json.loads(result.content.decode('utf-8'))
-        self.assertEqual(result.status_code, 200)
-        self.assertEqual(result_json['pagenum'], 1)
-        self.assertEqual(result_json['pagelen'], 0)
-        self.assertEqual(result_json['pagelen'], len(result_json['results']))
-
     def test_basic_search_with_staff(self):
 
         self.client.login(username='admin', password='admin')
@@ -291,6 +289,7 @@ class CatalogueSearchTestCase(WirecloudTestCase):
         self.assertEqual(response.status_code, 200)
         result_json = json.loads(response.content.decode('utf-8'))
         self.assertEqual(result_json['pagenum'], 1)
+        self.assertEqual(result_json['pagelen'], 9)
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
         self.assertEqual(result_json['total'], result_json['pagelen'])
         n = result_json['pagelen'] + sum([len(i['others']) for i in result_json['results']])
@@ -321,55 +320,14 @@ class CatalogueSearchTestCase(WirecloudTestCase):
                 self.assertEqual(result['image'], '')
                 self.assertEqual(result['smartphoneimage'], '')
 
-    def test_basic_search_letter_typo_correction(self):
-
-        self.client.login(username='myuser', password='admin')
-
-        # Search using a word with a incorrect letter: wercloud (full word: wirecloud)
-        result = self.client.get(self.base_url + '?q=wercloud')
-        result_json = json.loads(result.content.decode('utf-8'))
-        self.assertEqual(result.status_code, 200)
-        self.assertEqual(result_json['corrected_q'], 'wirecloud')
-        self.assertEqual(result_json['pagelen'], len(self.WIRECLOUD_RESULTS))
-        self.assertEqual(result_json['pagelen'], len(result_json['results']))
-        self.assertEqual(set([component['uri'] for component in result_json['results']]), self.WIRECLOUD_RESULTS)
-
-    def test_basic_search_unicode_letter(self):
-
-        self.client.login(username='myuser', password='admin')
-
-        # Search using a word with a incorrect letter: wercloud (full word: wirecloud)
-        result = self.client.get(self.base_url + '?q=wírecloud')
-        result_json = json.loads(result.content.decode('utf-8'))
-        self.assertEqual(result.status_code, 200)
-        self.assertEqual(result_json['corrected_q'], 'wirecloud')
-        self.assertEqual(result_json['pagelen'], len(self.WIRECLOUD_RESULTS))
-        self.assertEqual(result_json['pagelen'], len(result_json['results']))
-        self.assertEqual(set([component['uri'] for component in result_json['results']]), self.WIRECLOUD_RESULTS)
-
-    def test_basic_search_missing_letter_correction(self):
-
-        self.client.login(username='myuser', password='admin')
-
-        # Search using a word with a missing letter: mashble (full word: mashable)
-        result = self.client.get(self.base_url + '?q=mashble')
-        result_json = json.loads(result.content.decode('utf-8'))
-        self.assertEqual(result.status_code, 200)
-        self.assertEqual(result_json['corrected_q'], 'mashable')
-        self.assertEqual(result_json['pagelen'], len(self.MASHABLE_RESULTS))
-        self.assertEqual(result_json['pagelen'], len(result_json['results']))
-        self.assertEqual(set([component['uri'] for component in result_json['results']]), self.MASHABLE_RESULTS)
-
-    def test_basic_search_partial_word_correction(self):
+    def test_basic_search_partial_word(self):
 
         self.client.login(username='myuser', password='admin')
 
         # Search using a partial word: ashabl (full word: mashable)
-        # Whoosh uses maxdist = 2 by default
         result = self.client.get(self.base_url + '?q=ashabl')
         result_json = json.loads(result.content.decode('utf-8'))
         self.assertEqual(result.status_code, 200)
-        self.assertEqual(result_json['corrected_q'], 'mashable')
         self.assertEqual(result_json['pagelen'], len(self.MASHABLE_RESULTS))
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
         self.assertEqual(set([component['uri'] for component in result_json['results']]), self.MASHABLE_RESULTS)
@@ -379,12 +337,11 @@ class CatalogueSearchTestCase(WirecloudTestCase):
         self.client.login(username='myuser', password='admin')
 
         # Search using a prefix: wire (full word: wirecloud)
-        result = self.client.get(self.base_url + '?q=wire*')
+        result = self.client.get(self.base_url + '?q=wire')
         result_json = json.loads(result.content.decode('utf-8'))
         self.assertEqual(result.status_code, 200)
-        self.assertNotIn('corrected_q', result_json)
-        self.assertEqual(result_json['pagelen'], len(self.WIRECLOUD_RESULTS))
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
+        self.assertEqual(result_json['pagelen'], len(self.WIRECLOUD_RESULTS))
         self.assertEqual(set([component['uri'] for component in result_json['results']]), self.WIRECLOUD_RESULTS)
 
     def test_advanced_search_phrase_with_prefix(self):
@@ -393,71 +350,21 @@ class CatalogueSearchTestCase(WirecloudTestCase):
 
         # Search a full word: weather
         # Jointly with a prefix: inter (full word: interface)
-        result = self.client.get(self.base_url + '?q=weather+inter*')
+        result = self.client.get(self.base_url + '?q=weather+inter')
         result_json = json.loads(result.content.decode('utf-8'))
         self.assertEqual(result.status_code, 200)
-        self.assertNotIn('corrected_q', result_json)
         self.assertEqual(result_json['pagelen'], 1)
         self.assertEqual(result_json['pagelen'], len(result_json['results']))
         self.assertEqual(result_json['results'][0]['version'], "1.5.5")
         self.assertEqual(len(result_json['results'][0]['others']), 0)
 
 
-class CatalogueSuggestionTestCase(WirecloudTestCase):
-
-    fixtures = ('catalogue_search_data',)
-    tags = ('wirecloud-catalogue', 'wirecloud-catalogue-suggestions', 'wirecloud-noselenium', 'wirecloud-catalogue-noselenium')
-
-    @classmethod
-    def setUpClass(cls):
-
-        super(CatalogueSuggestionTestCase, cls).setUpClass()
-        cls.base_url = reverse('wirecloud_catalogue.resource_suggestion')
-
-    def setUp(self):
-
-        super(CatalogueSuggestionTestCase, self).setUp()
-        self.client = Client()
-        self.client.login(username='admin', password='admin')
-
-    def test_basic_suggestion(self):
-
-        response = self.client.get(self.base_url)
-        self.assertEqual(response.status_code, 200)
-        result_json = json.loads(response.content.decode('utf-8'))
-        self.assertEqual(len(result_json['terms']), 30)
-
-    def test_suggestion_limit(self):
-
-        response = self.client.get(self.base_url + '?limit=20')
-        self.assertEqual(response.status_code, 200)
-        result_json = json.loads(response.content.decode('utf-8'))
-        self.assertEqual(len(result_json['terms']), 20)
-
-    def test_suggestions_invalid_prefix(self):
-
-        response = self.client.get(self.base_url + '?p=double+prefix')
-        self.assertEqual(response.status_code, 422)
-
-    def test_suggestions_invalid_limit(self):
-
-        response = self.client.get(self.base_url + '?limit=fail')
-        self.assertEqual(response.status_code, 422)
-
-    def test_basic_suggestion_using_prefix(self):
-
-        response = self.client.get(self.base_url + '?p=wire')
-        self.assertEqual(response.status_code, 200)
-        result_json = json.loads(response.content.decode('utf-8'))
-        self.assertEqual(len(result_json['terms']), 8)
-        for term in result_json['terms']:
-            self.assertTrue(term.startswith('wire'))
-
-
-class CatalogueAPITestCase(WirecloudTestCase):
+class CatalogueAPITestCase(WirecloudTestCase, TransactionTestCase):
 
     fixtures = ('catalogue_test_data',)
     tags = ('wirecloud-catalogue', 'wirecloud-noselenium', 'wirecloud-catalogue-noselenium')
+    populate = False
+    use_search_indexes = False
 
     @classmethod
     def setUpClass(cls):
@@ -664,9 +571,10 @@ class CatalogueAPITestCase(WirecloudTestCase):
             self.assertIn('changelog', response_text)
 
 
-class WGTDeploymentTestCase(WirecloudTestCase):
+class WGTDeploymentTestCase(WirecloudTestCase, TransactionTestCase):
 
     tags = ('wirecloud-catalogue', 'wirecloud-noselenium', 'wirecloud-catalogue-noselenium')
+    populate = False
 
     def setUp(self):
         super(WGTDeploymentTestCase, self).setUp()
