@@ -19,7 +19,7 @@ MANAGERS = ADMINS
 
 DATABASES = {
     'default': {
-        'ENGINE': {{ db_engine }},       # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
+        'ENGINE': {{ db_engine }},       # Add 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
         'NAME': {{ db_name }},           # Or path to database file if using sqlite3.
         # The following settings are not used with sqlite3:
         'USER': '',
@@ -29,6 +29,13 @@ DATABASES = {
     }
 }
 
+HAYSTACK_CONNECTIONS = {
+    'default': {
+        'ENGINE': 'wirecloud.commons.haystack_backends.whoosh_backend.WhooshEngine',
+        'PATH': path.join(BASEDIR, 'index'),
+    },
+}
+
 # Hosts/domain names that are valid for this site; required if DEBUG is False
 # See https://docs.djangoproject.com/en/1.5/ref/settings/#allowed-hosts
 ALLOWED_HOSTS = ['*']
@@ -100,6 +107,7 @@ INSTALLED_APPS += (
     # 'django.contrib.sites',
     'wirecloud.oauth2provider',
     'wirecloud.fiware',
+    'haystack'
 )
 
 # Login/logout URLs
