@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2016 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -17,6 +17,21 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
+from django.utils.encoding import python_2_unicode_compatible
 
-class Http403(Exception):
-    pass
+
+@python_2_unicode_compatible
+class HttpBadCredentials(Exception):
+
+    def __init__(self, message, error_info=None):
+        self.message = message
+        self.error_info = error_info
+
+    def __str__(self):
+        return self.message
+
+
+class ErrorResponse(Exception):
+
+    def __init__(self, response):
+        self.response = response
