@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2008-2016 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -17,13 +17,17 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
+
+from importlib import import_module
+
 from django.contrib.auth.middleware import get_user
-from django.contrib.auth.models import AnonymousUser
-from django.core.exceptions import MiddlewareNotUsed
 from django.core.urlresolvers import reverse
-from django.utils.importlib import import_module
 from django.utils.functional import SimpleLazyObject
 from django.utils.http import http_date, parse_http_date_safe
+from django.utils.translation import ugettext as _
+
+from wirecloud.commons.exceptions import HttpBadCredentials
 
 
 class URLMiddleware(object):
@@ -143,15 +147,17 @@ def get_api_user(request):
     from wirecloud.platform.plugins import get_api_auth_backends
 
     parts = request.META['HTTP_AUTHORIZATION'].split(' ', 1)
-    if len(parts) == 0:
-        return AnonymousUser()
+    if len(parts) != 2:
+        raise HttpBadCredentials(_('Bad credentials'))
 
     (auth_type, token) = parts
     backends = get_api_auth_backends()
     try:
         return backends[auth_type](auth_type, token)
+    except HttpBadCredentials:
+        raise
     except:
-        return AnonymousUser()
+        raise HttpBadCredentials(_('Bad credentials'), '%(auth_type)s realm="WireCloud", error="invalid_token", error_description="bad credentials"' % {"auth_type": auth_type})
 
 
 class AuthenticationMiddleware(object):
@@ -174,7 +180,7 @@ class ConditionalGetMiddleware(object):
     """
     def process_response(self, request, response):
         response['Date'] = http_date()
-        if not response.has_header('Content-Length'):
+        if not response.has_header('Content-Length') and not response.streaming:
             response['Content-Length'] = str(len(response.content))
 
         if response.has_header('ETag'):
@@ -184,6 +190,7 @@ class ConditionalGetMiddleware(object):
                 # automatically removes content for this status code (in
                 # http.conditional_content_removal()).
                 response.status_code = 304
+                return response
 
         if response.has_header('Last-Modified'):
             if_modified_since = request.META.get('HTTP_IF_MODIFIED_SINCE')
