@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2008-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2008-2016 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -18,16 +18,18 @@
  *     <http://www.gnu.org/licenses/>.
  *
  */
-/*global StyledElements, Wirecloud*/
 
-(function () {
+/* globals StyledElements */
+
+
+(function (utils) {
 
     "use strict";
 
     /**
      *
      */
-    var CheckBox = function StyledCheckBox(options) {
+    var CheckBox = function CheckBox(options) {
 
         var defaultOptions = {
             'initialValue': false,
@@ -36,13 +38,13 @@
             'secondInput': null,
             'value': true
         };
-        options = Wirecloud.Utils.merge(defaultOptions, options);
+        options = utils.merge(defaultOptions, options);
 
         // This is needed for backward compatibility
         if ('initiallyChecked' in options) {
             options.initialValue = options.initiallyChecked;
         }
-        StyledElements.StyledInputElement.call(this, options.initialValue, ['change']);
+        StyledElements.InputElement.call(this, options.initialValue, ['change']);
 
         this.wrapperElement = document.createElement("input");
         this.wrapperElement.className = 'checkbox';
@@ -58,51 +60,51 @@
             this.wrapperElement.setAttribute("id", options.id);
         }
 
-        this.value = options.value;
+        this.checkedValue = options.value;
         this.inputElement.setAttribute("value", options.value);
         this.secondInput = options.secondInput;
         this.setValue(options.initialValue);
 
         if (options.group instanceof StyledElements.ButtonsGroup) {
-            this.wrapperElement.setAttribute("name", options.group.getName());
+            this.wrapperElement.setAttribute("name", options.group.name);
             options.group.insertButton(this);
         } else if (typeof options.group === 'string') {
             this.wrapperElement.setAttribute("name", options.group);
         }
 
         /* Internal events */
-        this.inputElement.addEventListener('mousedown', Wirecloud.Utils.stopPropagationListener, true);
-        this.inputElement.addEventListener('click', Wirecloud.Utils.stopPropagationListener, true);
+        this.inputElement.addEventListener('mousedown', utils.stopPropagationListener, true);
+        this.inputElement.addEventListener('click', utils.stopPropagationListener, true);
         this.inputElement.addEventListener('change',
                                     function () {
                                         if (this.enabled) {
                                             if (this.secondInput != null) {
                                                 this.secondInput.setDisabled(!this.inputElement.checked);
                                             }
-                                            this.events.change.dispatch(this);
+                                            this.dispatchEvent('change');
                                         }
                                     }.bind(this),
                                     true);
     };
 
-    CheckBox.prototype = new StyledElements.StyledInputElement();
+    utils.inherit(CheckBox, StyledElements.InputElement);
 
     CheckBox.prototype.reset = function reset() {
         this.setValue(this.defaultValue);
     };
 
     CheckBox.prototype.getValue = function getValue() {
-        if (this.value === true && this.secondInput == null) {
+        if (this.checkedValue === true && this.secondInput == null) {
             return this.inputElement.checked;
         } else if (this.secondInput == null) {
-            return this.inputElement.checked ? this.value : null;
+            return this.inputElement.checked ? this.checkedValue : null;
         } else {
             return this.secondInput.getValue();
         }
     };
 
     CheckBox.prototype.setValue = function setValue(newValue) {
-        this.inputElement.checked = newValue != null && newValue != false;
+        this.inputElement.checked = newValue != null && newValue !== false;
         if (this.secondInput != null) {
             this.secondInput.setDisabled(!this.inputElement.checked);
             if (this.inputElement.checked) {
@@ -111,5 +113,6 @@
         }
     };
 
-    StyledElements.StyledCheckBox = CheckBox;
-})();
+    StyledElements.CheckBox = CheckBox;
+
+})(StyledElements.Utils);
