@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2012 Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2016 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,25 +19,35 @@
  *
  */
 
-/*globals StyledElements, Wirecloud*/
+/* globals StyledElements */
 
-(function () {
+
+(function (utils) {
 
     "use strict";
 
+    var visibilityChangeListener = function visibilityChangeListener() {
+        if (this.popup_menu.isVisible()) {
+            this.wrapperElement.classList.add('open');
+        } else {
+            this.wrapperElement.classList.remove('open');
+        }
+    };
+
     var PopupButton = function PopupButton(options) {
         var defaultOptions = {
+            'menuOptions': null,
             'menu': null
         };
-        options = Wirecloud.Utils.merge(defaultOptions, options);
+        options = utils.merge(defaultOptions, options);
 
-        StyledElements.StyledButton.call(this, options);
+        StyledElements.Button.call(this, options);
 
         if (options.menu != null) {
             this.popup_menu = options.menu;
             this._owned_popup_menu = false;
         } else {
-            this.popup_menu = new StyledElements.PopupMenu(options.menuOptions);
+            this.popup_menu = new this.PopupMenu(options.menuOptions);
             this._owned_popup_menu = true;
         }
 
@@ -49,23 +59,56 @@
             }
         }.bind(this));
 
-        this._visibilityChangeListener = function () {
-            if (this.popup_menu.isVisible()) {
-                this.wrapperElement.classList.add('open');
-            } else {
-                this.wrapperElement.classList.remove('open');
-            }
-        }.bind(this);
+        this._visibilityChangeListener = visibilityChangeListener.bind(this);
         this.popup_menu.addEventListener('visibilityChange', this._visibilityChangeListener);
     };
-    PopupButton.prototype = new StyledElements.StyledButton({extending: true});
+    utils.inherit(PopupButton, StyledElements.Button);
+    PopupButton.prototype.PopupMenu = StyledElements.PopupMenu;
+
+    /**
+     * @override
+     */
+    PopupButton.prototype._onkeydown = function _onkeydown(event, key) {
+
+        switch (key) {
+        case 'ArrowDown':
+            event.preventDefault();
+            this.popup_menu.show(this.getBoundingClientRect()).moveFocusDown();
+            break;
+        case 'ArrowUp':
+            event.preventDefault();
+            this.popup_menu.show(this.getBoundingClientRect()).moveFocusUp();
+            break;
+        case ' ':
+        case 'Enter':
+            this._clickCallback(event);
+            break;
+        case 'Tab':
+            if (this.popup_menu.hasEnabledItem()) {
+                event.preventDefault();
+                this.popup_menu.moveFocusDown();
+            }
+            break;
+        default:
+            // Quit when this doesn't handle the key event.
+            break;
+        }
+    };
 
     PopupButton.prototype.getPopupMenu = function getPopupMenu() {
         return this.popup_menu;
     };
 
+    PopupButton.prototype.replacePopupMenu = function replacePopupMenu(new_popup_menu) {
+        if (this._owned_popup_menu) {
+            this.popup_menu.destroy();
+            this._owned_popup_menu = false;
+        }
+        this.popup_menu = new_popup_menu;
+    };
+
     PopupButton.prototype.destroy = function destroy() {
-        StyledElements.StyledButton.prototype.destroy.call(this);
+        StyledElements.Button.prototype.destroy.call(this);
 
         if (this._owned_popup_menu) {
             this.popup_menu.destroy();
@@ -76,4 +119,5 @@
     };
 
     StyledElements.PopupButton = PopupButton;
-})();
+
+})(StyledElements.Utils);
