@@ -1,28 +1,54 @@
-/*global StyledElements*/
+/*
+ *     Copyright (c) 2008-2016 CoNWeT Lab., Universidad Politécnica de Madrid
+ *
+ *     This file is part of Wirecloud Platform.
+ *
+ *     Wirecloud Platform is free software: you can redistribute it and/or
+ *     modify it under the terms of the GNU Affero General Public License as
+ *     published by the Free Software Foundation, either version 3 of the
+ *     License, or (at your option) any later version.
+ *
+ *     Wirecloud is distributed in the hope that it will be useful, but WITHOUT
+ *     ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ *     FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
+ *     License for more details.
+ *
+ *     You should have received a copy of the GNU Affero General Public License
+ *     along with Wirecloud Platform.  If not, see
+ *     <http://www.gnu.org/licenses/>.
+ *
+ */
 
-(function () {
+/* globals StyledElements */
+
+
+(function (utils) {
 
     "use strict";
 
     /**
      *
      */
-    var SubMenuItem = function SubMenuItem(text, handler, options) {
+    var SubMenuItem = function SubMenuItem(text, options) {
 
         if (arguments.length === 0) {
             return true;
         }
 
-        options = Wirecloud.Utils.merge({
+        options = utils.merge({
             'position': ['right-bottom', 'left-bottom']
         }, options);
 
         StyledElements.PopupMenuBase.call(this, options);
+        this.wrapperElement.classList.add('se-popup-submenu');
 
-        this.menuItem = new StyledElements.MenuItem(text, handler);
+        this.menuItem = new StyledElements.MenuItem(text, function () {
+            this.submenu.show(this.getBoundingClientRect());
+        });
         this.menuItem.addClassName('submenu');
+        this.menuItem.submenu = this;
     };
-    SubMenuItem.prototype = new StyledElements.PopupMenuBase({extending: true});
+    utils.inherit(SubMenuItem, StyledElements.PopupMenuBase);
 
     SubMenuItem.prototype._getContext = function _getContext() {
         if (this.parentMenu instanceof SubMenuItem) {
@@ -46,7 +72,7 @@
 
         this.parentMenu.addEventListener('itemOver', function (popupMenu, item) {
             if (item === this.menuItem) {
-                this.show(this.menuItem.wrapperElement.getBoundingClientRect());
+                this.show(this.menuItem.getBoundingClientRect());
             } else {
                 this.hide();
             }
@@ -59,8 +85,11 @@
 
     SubMenuItem.prototype.addEventListener = function addEventListener(eventId, handler) {
         switch (eventId) {
-        case 'mouseover':
+        case 'mouseenter':
+        case 'mouseleave':
         case 'click':
+        case 'blur':
+        case 'focus':
             return this.menuItem.addEventListener(eventId, handler);
         default:
             return StyledElements.PopupMenuBase.prototype.addEventListener.call(this, eventId, handler);
@@ -91,4 +120,4 @@
 
     StyledElements.SubMenuItem = SubMenuItem;
 
-})();
+})(StyledElements.Utils);
