@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2013-2014 Universidad Politécnica de Madrid
+ *     Copyright (c) 2013-2016 Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,8 @@
  *
  */
 
-/*global Wirecloud*/
+/* globals Wirecloud */
+
 
 (function () {
 
@@ -29,16 +30,13 @@
         return true;
     };
 
-    var _cancel = function () {
-        return false;
-    };
-
     /**
      * @param draggableElement {HTMLElement} Element to drag
      * @param handler {HTMLElement} Element where the drag & drop operation must to be started
      * @param data {Object} context
      */
     var Draggable = function Draggable(handler, data, onStart, onDrag, onFinish, canBeDragged, onScroll) {
+        var lastClientX, lastClientY;
         var xStart = 0, yStart = 0, xScrollStart = 0, yScrollStart = 0;
         var xScrollDelta, yScrollDelta;
         var dragboardCover;
@@ -72,26 +70,24 @@
             handler.addEventListener("mousedown", startdrag, false);
             handler.addEventListener("touchstart", startdrag, false);
 
-            document.onmousedown = null; // reenable context menu
-            document.onselectstart = null; // reenable text selection in IE
-            document.oncontextmenu = null; // reenable text selection
+            document.removeEventListener('contextmenu', Wirecloud.Utils.preventDefaultListener); // reenable context menu
+            document.removeEventListener('mousedown', Wirecloud.Utils.preventDefaultListener); // reenable text selection
         };
 
         // fire each time it's dragged
         drag = function drag(e) {
-            var clientX, clientY;
 
             if ('touches' in e) {
-                clientX = e.touches[0].clientX;
-                clientY = e.touches[0].clientY;
+                lastClientX = e.touches[0].clientX;
+                lastClientY = e.touches[0].clientY;
                 // Work around chrome bug: https://code.google.com/p/chromium/issues/detail?id=150779
                 e.preventDefault();
             } else {
-                clientX = e.clientX;
-                clientY = e.clientY;
+                lastClientX = e.clientX;
+                lastClientY = e.clientY;
             }
-            var xDelta = clientX - xStart - xScrollDelta;
-            var yDelta = clientY - yStart - yScrollDelta;
+            var xDelta = lastClientX - xStart - xScrollDelta;
+            var yDelta = lastClientY - yStart - yScrollDelta;
 
             onDrag(e, draggable, data, xDelta, yDelta);
         };
@@ -101,16 +97,16 @@
 
             // Only attend to left button (or right button for left-handed persons) events
             if (e.type === 'mousedown' && e.button !== 0) {
-                return false;
+                return;
             }
 
             if (!canBeDragged(draggable, data)) {
                 return false;
             }
 
-            document.oncontextmenu = _cancel; // disable context menu
-            document.onmousedown = _cancel; // disable text selection in Firefox
-            document.onselectstart = _cancel; // disable text selection in IE
+            e.preventDefault(); // disable text selection caused by this event
+            document.addEventListener('contextmenu', Wirecloud.Utils.preventDefaultListener); // disable context menu
+            document.addEventListener('mousedown', Wirecloud.Utils.preventDefaultListener); // disable text selection in Firefox
             handler.removeEventListener("mousedown", startdrag, false);
             handler.removeEventListener("touchstart", startdrag, false);
 
@@ -121,6 +117,8 @@
                 xStart = e.clientX;
                 yStart = e.clientY;
             }
+            lastClientX = xStart;
+            lastClientY = yStart;
 
             document.addEventListener("mouseup", enddrag, false);
             document.addEventListener("touchend", enddrag, false);
@@ -151,12 +149,12 @@
                 yScrollStart = parseInt(dragboard.scrollTop, 10);
                 xScrollStart = parseInt(dragboard.scrollLeft, 10);
 
-                dragboardCover.addEventListener("scroll", scroll, true);
+                dragboard.addEventListener("scroll", scroll, true);
 
                 dragboard.insertBefore(dragboardCover, dragboard.firstChild);
             }
+
             e.stopPropagation();
-            return false;
         };
 
         // fire each time the dragboard is scrolled while dragging
@@ -164,29 +162,26 @@
 
             var dragboard = dragboardCover.parentNode;
             dragboardCover.style.height = dragboard.scrollHeight + "px";
-            var scrollTop = parseInt(dragboard.scrollTop, 10);
 
-            // yScrollDeltaDiff = diff between old scroll y delta and the new scroll y delta
-            var oldYDelta = yScrollDelta;
+            var scrollTop = parseInt(dragboard.scrollTop, 10);
             yScrollDelta = yScrollStart - scrollTop;
-            var yScrollDeltaDiff = yScrollDelta - oldYDelta;
 
             var scrollLeft = parseInt(dragboard.scrollLeft, 10);
-            // xScrollDeltaDiff = diff between old scroll x delta and the new scroll x delta
-            var oldXDelta = xScrollDelta;
             xScrollDelta = xScrollStart - scrollLeft;
-            var xScrollDeltaDiff = xScrollDelta - oldXDelta;
 
-            onScroll(e, draggable, data, xScrollDeltaDiff, yScrollDeltaDiff);
+            var xDelta = lastClientX - xStart - xScrollDelta;
+            var yDelta = lastClientY - yStart - yScrollDelta;
+
+            onDrag(e, draggable, data, xDelta, yDelta);
         };
 
         // add mousedown event listener
         handler.addEventListener("mousedown", startdrag, false);
         handler.addEventListener("touchstart", startdrag, false);
 
-        /**********
-         * Public methods
-         **********/
+        // =====================================================================
+        // PUBLIC MEMBERS
+        // =====================================================================
 
         this.destroy = function destroy() {
             handler.removeEventListener("mousedown", startdrag, false);
