@@ -18,6 +18,7 @@
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 import codecs
+import copy
 from six.moves.http_cookies import SimpleCookie
 from io import BytesIO
 import mimetypes
@@ -27,24 +28,25 @@ import shutil
 import stat
 import sys
 from tempfile import mkdtemp
+import time
 from six.moves.urllib.error import URLError, HTTPError
 from six.moves.urllib.parse import unquote, urlparse
 
+from django.apps import apps
 from django.contrib.auth.models import Group, User
 from django.contrib.staticfiles import finders
 from django.core import management
-from django.test import LiveServerTestCase
-from django.test import TransactionTestCase
+from django.test import LiveServerTestCase, TestCase
 from django.test.client import Client
 from django.utils import translation
 import mock
+import haystack
 from six import text_type
 
 from wirecloud.platform.localcatalogue.utils import fix_dev_version, install_resource
 from wirecloud.platform.widget import utils as showcase
 from wirecloud.platform.workspace.utils import create_workspace
 from wirecloud.catalogue import utils as catalogue
-from wirecloud.commons.searchers import get_available_search_engines
 from wirecloud.commons.utils.http import REASON_PHRASES
 from wirecloud.commons.utils.remote import WirecloudRemoteTestCase, FieldTester
 from wirecloud.commons.utils.wgt import WgtDeployer, WgtFile
@@ -300,14 +302,8 @@ class FakeNetwork(object):
 
 def prepare_temporal_resource_directories(cls):
 
-    from django.conf import settings
-
     cls.tmp_dir = mkdtemp()
 
-    # Whoosh indexes
-    cls.old_index_dir = settings.WIRECLOUD_INDEX_DIR
-    settings.WIRECLOUD_INDEX_DIR = os.path.join(cls.tmp_dir, 'whoosh_indexes')
-
     # catalogue deployer
     cls.old_catalogue_deployer = catalogue.wgt_deployer
     cls.catalogue_tmp_dir_backup = os.path.join(cls.tmp_dir, 'catalogue_backup')
@@ -340,14 +336,30 @@ def prepare_temporal_resource_directories(cls):
         os.mkdir(cls.catalogue_tmp_dir_backup)
 
 
-class WirecloudTestCase(TransactionTestCase):
+DEFAULT_TEST_HAYSTACK_CONNECTIONS = {
+    'default': {
+        'ENGINE': 'wirecloud.commons.haystack_backends.whoosh_backend.WhooshEngine'
+    }
+}
+
+
+class WirecloudTestCase(object):
 
     base_resources = ()
     populate = True
+    use_search_indexes = True
+    clear_search_indexes = None
 
     @classmethod
     def setUpClass(cls):
 
+        if cls.use_search_indexes is False:
+            cls.clear_search_indexes = False
+        elif cls.clear_search_indexes is None and issubclass(cls, TestCase):
+            cls.clear_search_indexes = False
+        elif cls.clear_search_indexes is None:
+            cls.clear_search_indexes = True
+
         # Setup languages
         from django.conf import settings
 
@@ -372,6 +384,24 @@ class WirecloudTestCase(TransactionTestCase):
 
         prepare_temporal_resource_directories(cls)
 
+        # Prepare haystack configuration
+        if cls.use_search_indexes:
+            cls.old_haystack_conf = settings.HAYSTACK_CONNECTIONS
+            try:
+                settings.HAYSTACK_CONNECTIONS = copy.deepcopy(settings.TEST_HAYSTACK_CONNECTIONS)
+                # Update whoosh index dir if not set by user
+                if settings.HAYSTACK_CONNECTIONS['default']['ENGINE'] == 'wirecloud.commons.haystack_backends.whoosh_backend.WhooshEngine' and settings.HAYSTACK_CONNECTIONS['default'].get("PATH") is None:
+                    settings.HAYSTACK_CONNECTIONS['default']['PATH'] = os.path.join(cls.tmp_dir, 'test_whoosh_indexes')
+            except:
+                settings.HAYSTACK_CONNECTIONS = copy.deepcopy(DEFAULT_TEST_HAYSTACK_CONNECTIONS)
+                settings.HAYSTACK_CONNECTIONS['default']['PATH'] = os.path.join(cls.tmp_dir, 'test_whoosh_indexes')
+
+            # Reload the connection
+            haystack.connections.connections_info = settings.HAYSTACK_CONNECTIONS
+            haystack.connections.reload('default')
+        else:
+            apps.get_app_config('haystack').signal_processor.teardown()
+
         super(WirecloudTestCase, cls).setUpClass()
 
     @classmethod
@@ -391,8 +421,16 @@ class WirecloudTestCase(TransactionTestCase):
         settings.LANGUAGE_CODE = cls.old_LANGUAGE_CODE
         settings.DEFAULT_LANGUAGE = cls.old_DEFAULT_LANGUAGE
 
-        # Restore old index dir
-        settings.WIRECLOUD_INDEX_DIR = cls.old_index_dir
+        # Restore old haystack configuration
+        if not cls.use_search_indexes:
+            apps.get_app_config('haystack').signal_processor.setup()
+        else:
+            if not cls.clear_search_indexes:
+                # If self.clear_search_indexes is True, this step is done in a per
+                # test basis in the tearDown method
+                management.call_command('clear_index', interactive=False, verbosity=0)
+
+            settings.HAYSTACK_CONNECTIONS = cls.old_haystack_conf
 
         # Clear cache
         from django.core.cache import cache
@@ -422,6 +460,8 @@ class WirecloudTestCase(TransactionTestCase):
         # Restore English as the default language
         self.changeLanguage('en')
 
+        super(WirecloudTestCase, self).setUp()
+
         # Populate initial db
         if self.populate:
             management.call_command('populate', verbosity=0, interactive=False)
@@ -430,9 +470,14 @@ class WirecloudTestCase(TransactionTestCase):
 
         from django.conf import settings
 
-        for searcher in get_available_search_engines():
-            searcher.clear_cache()
-        shutil.rmtree(settings.WIRECLOUD_INDEX_DIR, ignore_errors=True)
+        if self.clear_search_indexes:
+            management.call_command('clear_index', interactive=False, verbosity=0)
+
+            # Reload the connection
+            haystack.connections.connections_info = settings.HAYSTACK_CONNECTIONS
+            haystack.connections.reload('default')
+
+        super(WirecloudTestCase, self).tearDown()
 
     def changeLanguage(self, new_language):
 
@@ -521,6 +566,10 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
     # Only affecting Django 1.11+
     host = os.environ.get('DJANGO_LIVE_TEST_SERVER_HOST', 'localhost')
 
+    populate = True
+    use_search_indexes = True
+    clear_search_indexes = True
+
     @classmethod
     def setUpClass(cls):
 
@@ -547,6 +596,24 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
 
         prepare_temporal_resource_directories(cls)
 
+        # Prepare haystack configuration
+        if cls.use_search_indexes:
+            cls.old_haystack_conf = settings.HAYSTACK_CONNECTIONS
+            try:
+                settings.HAYSTACK_CONNECTIONS = copy.deepcopy(settings.TEST_HAYSTACK_CONNECTIONS)
+                # Update whoosh index dir if not set by user
+                if settings.HAYSTACK_CONNECTIONS['default']['ENGINE'] == 'wirecloud.commons.haystack_backends.whoosh_backend.WhooshEngine' and settings.HAYSTACK_CONNECTIONS['default'].get("PATH") is None:
+                    settings.HAYSTACK_CONNECTIONS['default']['PATH'] = os.path.join(cls.tmp_dir, 'test_whoosh_indexes')
+            except:
+                settings.HAYSTACK_CONNECTIONS = copy.deepcopy(DEFAULT_TEST_HAYSTACK_CONNECTIONS)
+                settings.HAYSTACK_CONNECTIONS['default']['PATH'] = os.path.join(cls.tmp_dir, 'test_whoosh_indexes')
+
+            # Reload the connection
+            haystack.connections.connections_info = settings.HAYSTACK_CONNECTIONS
+            haystack.connections.reload('default')
+        else:
+            apps.get_app_config('haystack').signal_processor.teardown()
+
         # Browsers doesn't use content negotiation using ETags with HTTP 1.0 servers
         # Force Django to use HTTP 1.1 when using the runserver command
         from wsgiref import simple_server
@@ -573,17 +640,28 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
         catalogue.wgt_deployer = cls.old_catalogue_deployer
         showcase.wgt_deployer = cls.old_deployer
 
-        # Restore old index dir
-        settings.WIRECLOUD_INDEX_DIR = cls.old_index_dir
-
         settings.LANGUAGES = cls.old_LANGUAGES
         settings.LANGUAGE_CODE = cls.old_LANGUAGE_CODE
         settings.DEFAULT_LANGUAGE = cls.old_DEFAULT_LANGUAGE
 
+        # Restore old haystack configuration
+        if not cls.use_search_indexes:
+            apps.get_app_config('haystack').signal_processor.setup()
+        else:
+            if not cls.clear_search_indexes:
+                # If self.clear_search_indexes is True, this step is done in a per
+                # test basis in the tearDown method
+                management.call_command('clear_index', interactive=False, verbosity=0)
+
+            settings.HAYSTACK_CONNECTIONS = cls.old_haystack_conf
+
         super(WirecloudSeleniumTestCase, cls).tearDownClass()
 
     def setUp(self):
 
+        haystack.connections.reload('default')
+        management.call_command('rebuild_index', interactive=False, verbosity=0)
+
         from django.core.cache import cache
 
         restoretree(self.localcatalogue_tmp_dir_backup, self.localcatalogue_tmp_dir)
@@ -601,10 +679,14 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
     def tearDown(self):
 
         from django.conf import settings
+        if self.clear_search_indexes:
+            management.call_command('clear_index', interactive=False, verbosity=0)
 
-        for searcher in get_available_search_engines():
-            searcher.clear_cache()
-        shutil.rmtree(settings.WIRECLOUD_INDEX_DIR, ignore_errors=True)
+            # Reload the connection
+            haystack.connections.connections_info = settings.HAYSTACK_CONNECTIONS
+            haystack.connections.reload('default')
+
+            time.sleep(0.2)
 
         LiveServerTestCase.tearDown(self)
         WirecloudRemoteTestCase.tearDown(self)
