@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2014 Universidad Politécnica de Madrid
+# Copyright (c) 2008-2016 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -17,18 +17,22 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-import json
+from __future__ import unicode_literals
 
+import json
+import six
+
+from django.contrib.auth.models import User
 from django.core.cache import cache
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
 from django.utils.translation import gettext_lazy as _
 
 from wirecloud.commons.baseviews import Resource
-from wirecloud.commons.utils.cache import no_cache
-from wirecloud.commons.utils.http import authentication_required, build_error_response, supported_request_mime_types
+from wirecloud.commons.utils.http import authentication_required, build_error_response, consumes, parse_json_request
 from wirecloud.commons.utils.transaction import commit_on_http_success
-from wirecloud.platform.models import PlatformPreference, WorkspacePreference, Tab, TabPreference, update_session_lang, Workspace
+from wirecloud.platform.plugins import get_tab_preferences, get_workspace_preferences
+from wirecloud.platform.models import Organization, PlatformPreference, WorkspacePreference, Tab, TabPreference, update_session_lang, Workspace
 
 
 def update_preferences(user, preferences_json):
@@ -45,7 +49,7 @@ def update_preferences(user, preferences_json):
         else:
             preference = PlatformPreference(user=user, name=name)
 
-        preference.value = unicode(preference_data['value'])
+        preference.value = preference_data['value']
         preference.save()
 
 
@@ -67,8 +71,30 @@ def parseInheritableValues(values):
     return _values
 
 
+def make_tab_preferences_cache_key(tab):
+    return '_tab_preferences_cache/%s/%s' % (tab.id, tab.workspace.last_modified)
+
+
+def serialize_default_value(value):
+
+    if isinstance(value, six.text_type):
+        return value
+    else:
+        return json.dumps(value, ensure_ascii=False)
+
+
 def get_tab_preference_values(tab):
-    return parseInheritableValues(TabPreference.objects.filter(tab=tab.pk))
+    cache_key = make_tab_preferences_cache_key(tab)
+    values = cache.get(cache_key)
+    if values is None:
+        values = parseInheritableValues(tab.tabpreference_set.all())
+        for preference in get_tab_preferences():
+            if preference['name'] not in values:
+                values[preference['name']] = {'inherit': bool(preference.get('inheritByDefault', False)), 'value': serialize_default_value(preference['defaultValue'])}
+
+        cache.set(cache_key, values)
+
+    return values
 
 
 def update_tab_preferences(tab, preferences_json):
@@ -86,85 +112,97 @@ def update_tab_preferences(tab, preferences_json):
             preference = TabPreference(tab=tab, name=name)
 
         if 'value' in preference_data:
-            preference.value = unicode(preference_data['value'])
+            preference.value = preference_data['value']
 
         if 'inherit' in preference_data:
             preference.inherit = preference_data['inherit']
 
         preference.save()
 
-    from wirecloud.platform.get_data import _invalidate_cached_variable_values
-    _invalidate_cached_variable_values(tab.workspace)
+    tab.workspace.save()  # Invalidate workspace cache
 
-def make_workspace_preferences_cache_key(workspace_id):
-    return '_workspace_preferences_cache/' + str(workspace_id)
+
+def make_workspace_preferences_cache_key(workspace):
+    return '_workspace_preferences_cache/%s/%s' % (workspace.id, workspace.last_modified)
 
 
 def get_workspace_preference_values(workspace):
-    if isinstance(workspace, Workspace):
-        workspace_id = workspace.id
-    else:
-        workspace_id = int(workspace)
 
-    cache_key = make_workspace_preferences_cache_key(workspace_id)
+    cache_key = make_workspace_preferences_cache_key(workspace)
     values = cache.get(cache_key)
     if values is None:
-        values = parseInheritableValues(WorkspacePreference.objects.filter(workspace=workspace_id))
+        values = parseInheritableValues(workspace.workspacepreference_set.all())
+        for preference in get_workspace_preferences():
+            if preference['name'] not in values:
+                values[preference['name']] = {'inherit': bool(preference.get('inheritByDefault', False)), 'value': serialize_default_value(preference['defaultValue'])}
+
         cache.set(cache_key, values)
 
     return values
 
 
-def update_workspace_preferences(workspace, preferences_json):
-    _currentPreferences = WorkspacePreference.objects.filter(workspace=workspace)
+def update_workspace_preferences(workspace, preferences_json, invalidate_cache=True):
+
+    changes = False
+
+    # Create a preference instance dict
     currentPreferences = {}
-    for currentPreference in _currentPreferences:
+    for currentPreference in workspace.workspacepreference_set.all():
         currentPreferences[currentPreference.name] = currentPreference
 
+    # Update preference values
     for name in preferences_json.keys():
         preference_data = preferences_json[name]
+        pref_changes = False
 
         if name in currentPreferences:
             preference = currentPreferences[name]
         else:
             preference = WorkspacePreference(workspace=workspace, name=name)
+            changes = pref_changes = True
 
-        if 'value' in preference_data:
-            preference.value = unicode(preference_data['value'])
+        if isinstance(preference_data, dict):
+            if 'value' in preference_data and preference.value != preference_data['value']:
+                preference.value = preference_data['value']
+                changes = pref_changes = True
 
-        if 'inherit' in preference_data:
-            preference.inherit = preference_data['inherit']
+            if 'inherit' in preference_data and preference.inherit != preference_data['inherit']:
+                preference.inherit = preference_data['inherit']
+                changes = pref_changes = True
+        else:
+            if preference.value != preference_data:
+                preference.value = preference_data
+                changes = pref_changes = True
 
-        preference.save()
+            if preference.inherit is not False:
+                preference.inherit = False
+                changes = pref_changes = True
 
-    cache_key = make_workspace_preferences_cache_key(workspace.id)
-    cache.delete(cache_key)
+        if pref_changes:
+            preference.save()
 
-    from wirecloud.platform.get_data import _invalidate_cached_variable_values
-    _invalidate_cached_variable_values(workspace)
+    if invalidate_cache and changes:
+        cache_key = make_workspace_preferences_cache_key(workspace)
+        cache.delete(cache_key)
+        workspace.save()  # Invalidate workspace cache
 
 
 class PlatformPreferencesCollection(Resource):
 
-    @no_cache
     def read(self, request):
         if request.user.is_authenticated():
             result = parseValues(PlatformPreference.objects.filter(user=request.user))
         else:
             result = {}
 
-        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result, sort_keys=True), content_type='application/json; charset=UTF-8')
 
     @authentication_required
-    @supported_request_mime_types(('application/json',))
+    @consumes(('application/json',))
     @commit_on_http_success
     def create(self, request):
-        try:
-            preferences_json = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
 
+        preferences_json = parse_json_request(request)
         update_preferences(request.user, preferences_json)
 
         if 'language' in preferences_json:
@@ -176,7 +214,6 @@ class PlatformPreferencesCollection(Resource):
 class WorkspacePreferencesCollection(Resource):
 
     @authentication_required
-    @no_cache
     def read(self, request, workspace_id):
 
         # Check Workspace existance and owned by this user
@@ -184,12 +221,12 @@ class WorkspacePreferencesCollection(Resource):
         if not (request.user.is_superuser or workspace.users.filter(pk=request.user.pk).exists()):
             return build_error_response(request, 403, _('You are not allowed to read this workspace'))
 
-        result = get_workspace_preference_values(workspace.id)
+        result = get_workspace_preference_values(workspace)
 
-        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result, sort_keys=True), content_type='application/json; charset=UTF-8')
 
     @authentication_required
-    @supported_request_mime_types(('application/json',))
+    @consumes(('application/json',))
     @commit_on_http_success
     def create(self, request, workspace_id):
 
@@ -198,14 +235,27 @@ class WorkspacePreferencesCollection(Resource):
         if not (request.user.is_superuser or workspace.users.filter(pk=request.user.pk).exists()):
             return build_error_response(request, 403, _('You are not allowed to update this workspace'))
 
-        try:
-            preferences_json = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
+        preferences_json = parse_json_request(request)
+
+        if 'sharelist' in preferences_json:
+            workspace.users.clear()
+            workspace.groups.clear()
+            sharelist = json.loads(preferences_json['sharelist']['value'])
+            for item in sharelist:
+                try:
+                    user = User.objects.get(username=item['name'])
+                except User.DoesNotExist:
+                    continue
+
+                workspace.userworkspace_set.create(user=user)
+                try:
+                    workspace.groups.add(user.organization.group)
+                except Organization.DoesNotExist:
+                    pass
+            del preferences_json['sharelist']
 
         if 'public' in preferences_json:
-            workspace.public = preferences_json['public']['value']
+            workspace.public = preferences_json['public']['value'].strip().lower() == 'true'
             workspace.save()
             del preferences_json['public']
 
@@ -217,7 +267,6 @@ class WorkspacePreferencesCollection(Resource):
 class TabPreferencesCollection(Resource):
 
     @authentication_required
-    @no_cache
     def read(self, request, workspace_id, tab_id):
 
         # Check Tab existance and owned by this user
@@ -227,10 +276,10 @@ class TabPreferencesCollection(Resource):
 
         result = get_tab_preference_values(tab)
 
-        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result, sort_keys=True), content_type='application/json; charset=UTF-8')
 
     @authentication_required
-    @supported_request_mime_types(('application/json',))
+    @consumes(('application/json',))
     @commit_on_http_success
     def create(self, request, workspace_id, tab_id):
 
@@ -239,11 +288,7 @@ class TabPreferencesCollection(Resource):
         if not (request.user.is_superuser or tab.workspace.users.filter(pk=request.user.pk).exists()):
             return build_error_response(request, 403, _('You are not allowed to update this workspace'))
 
-        try:
-            preferences_json = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
+        preferences_json = parse_json_request(request)
 
         update_tab_preferences(tab, preferences_json)
         return HttpResponse(status=204)
