@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2013-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2013-2015 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,29 +19,54 @@
  *
  */
 
-/*global MashupPlatform*/
+/* globals MashupPlatform */
+
 
 (function () {
 
     "use strict";
 
     var platform = window.parent;
-    var resource = MashupPlatform.resource;
+    var Wirecloud = platform.Wirecloud;
+    var workspaceview = MashupPlatform.priv.workspaceview;
+    var resource = MashupPlatform.priv.resource;
+    var componentType = resource instanceof Wirecloud.Widget ? "widget" : "operator";
+    var guibuilder = new platform.StyledElements.GUIBuilder();
+
+    // HTTP module
+    Object.defineProperty(window.MashupPlatform, 'http', {value: {}});
+    Object.defineProperty(window.MashupPlatform.http, 'buildProxyURL', {value: Wirecloud.io.buildProxyURL});
+    Object.defineProperty(window.MashupPlatform.http, 'makeRequest', {
+        value: function makeRequest(url, options) {
+            url = new platform.URL(url, window.location);
+            if (!options.requestHeaders) {
+                options.requestHeaders = {};
+            }
+            options.requestHeaders["wirecloud-component-type"] = componentType;
+            options.requestHeaders["wirecloud-component-id"] = resource.id;
+            return Wirecloud.io.makeRequest(url, options);
+        }
+    });
+    Object.preventExtensions(window.MashupPlatform.http);
 
     // Platform context module
     Object.defineProperty(window.MashupPlatform, 'context', {value: {}});
     Object.defineProperty(window.MashupPlatform.context, 'getAvailableContext', {
         value: function getAvailableContext() {
-            return platform.Wirecloud.contextManager.getAvailableContext();
+            return Wirecloud.contextManager.getAvailableContext();
         }
     });
     Object.defineProperty(window.MashupPlatform.context, 'get', {
         value: function get(name) {
-            return platform.Wirecloud.contextManager.get(name);
+            return Wirecloud.contextManager.get(name);
         }
     });
     Object.defineProperty(window.MashupPlatform.context, 'registerCallback', {
         value: function registerCallback(callback) {
+            if (typeof callback !== "function") {
+                throw new TypeError('callback must be a function');
+            }
+
             resource.registerContextAPICallback('platform', callback);
         }
     });
@@ -60,22 +85,25 @@
     Object.defineProperty(window.MashupPlatform.mashup, 'context', {value: {}});
     Object.defineProperty(window.MashupPlatform.mashup.context, 'getAvailableContext', {
         value: function getAvailableContext() {
-            return platform.Wirecloud.activeWorkspace.contextManager.getAvailableContext();
+            return workspaceview.model.contextManager.getAvailableContext();
         }
     });
     Object.defineProperty(window.MashupPlatform.mashup.context, 'get', {
         value: function get(name) {
-            return platform.Wirecloud.activeWorkspace.contextManager.get(name);
+            return workspaceview.model.contextManager.get(name);
         }
     });
     Object.defineProperty(window.MashupPlatform.mashup.context, 'registerCallback', {
         value: function registerCallback(callback) {
+            if (typeof callback !== "function") {
+                throw new TypeError('callback must be a function');
+            }
+
             resource.registerContextAPICallback('mashup', callback);
         }
     });
     Object.preventExtensions(window.MashupPlatform.mashup.context);
 
-    Object.preventExtensions(window.MashupPlatform.mashup);
 
     // Prefs Module
     Object.defineProperty(window.MashupPlatform, 'prefs', {value: {}});
@@ -85,14 +113,16 @@
                 return resource.preferences[key].value;
             } else {
                 var exception_msg = platform.interpolate('"%(pref)s" is not a valid preference name', {pref: key}, true);
-                var log_msg = platform.interpolate('Error calling MashupPlatform.prefs.get: %(msg)s', {msg: exception_msg}, true);
-                resource.logManager.log(log_msg);
-                throw new MashupPlatform.prefs.PreferenceError(exception_msg);
+                throw new MashupPlatform.prefs.PreferenceDoesNotExistError(exception_msg);
             }
         }
     });
     Object.defineProperty(window.MashupPlatform.prefs, 'registerCallback', {
         value: function registerCallback(callback) {
+            if (typeof callback !== "function") {
+                throw new TypeError('callback must be a function');
+            }
+
             resource.registerPrefCallback(callback);
         }
     });
@@ -102,58 +132,100 @@
                 resource.preferences[key].value = value;
             } else {
                 var exception_msg = platform.interpolate('"%(pref)s" is not a valid preference name', {pref: key}, true);
-                var log_msg = platform.interpolate('Error calling MashupPlatform.prefs.set: %(msg)s', {msg: exception_msg}, true);
-                resource.logManager.log(log_msg);
-                throw new MashupPlatform.prefs.PreferenceError(exception_msg);
+                throw new MashupPlatform.prefs.PreferenceDoesNotExistError(exception_msg);
             }
         }
     });
-    Object.defineProperty(window.MashupPlatform.prefs, 'PreferenceError', {
-        value: platform.Wirecloud.PreferenceError
-    });
+    Object.defineProperty(window.MashupPlatform.prefs, 'PreferenceDoesNotExistError', {value: Wirecloud.PreferenceDoesNotExistError});
     Object.preventExtensions(window.MashupPlatform.prefs);
 
+
     // Wiring Module
     Object.defineProperty(window.MashupPlatform, 'wiring', {value: {}});
     Object.defineProperty(window.MashupPlatform.wiring, 'registerCallback', {
         value: function registerCallback(inputName, callback) {
+            if (typeof callback !== "function") {
+                throw new TypeError('callback must be a function');
+            }
+
             if (inputName in resource.inputs) {
                 resource.inputs[inputName].callback = callback;
             } else {
                 var exception_msg = platform.interpolate('"%(endpoint)s" is not a valid input endpoint', {endpoint: inputName}, true);
-                var log_msg = platform.interpolate('Error calling MashupPlatform.wiring.registerCallback: %(msg)s', {msg: exception_msg}, true);
-                resource.logManager.log(log_msg);
-                throw new MashupPlatform.wiring.EndpointError(exception_msg);
+                throw new MashupPlatform.wiring.EndpointDoesNotExistError(exception_msg);
             }
         }
     });
+    Object.defineProperty(window.MashupPlatform.wiring, 'registerStatusCallback', {
+        value: function registerCallback(callback) {
+            var wiring;
+
+            if (typeof callback !== "function") {
+                throw new TypeError('callback must be a function');
+            }
+
+            if ('wiring' in resource) {
+                wiring = resource.wiring;
+            } else {
+                wiring = resource.tab.workspace.wiring;
+            }
+            wiring.addEventListener('load', callback);
+        }
+    });
     Object.defineProperty(window.MashupPlatform.wiring, 'pushEvent', {
         value: function pushEvent(outputName, data, options) {
             if (outputName in resource.outputs) {
                 resource.outputs[outputName].propagate(data, options);
             } else {
                 var exception_msg = platform.interpolate('"%(endpoint)s" is not a valid output endpoint', {endpoint: outputName}, true);
-                var log_msg = platform.interpolate('Error calling MashupPlatform.wiring.pushEvent: %(msg)s', {msg: exception_msg}, true);
-                resource.logManager.log(log_msg);
-                throw new MashupPlatform.wiring.EndpointError(exception_msg);
+                throw new MashupPlatform.wiring.EndpointDoesNotExistError(exception_msg);
+            }
+        }
+    });
+    Object.defineProperty(window.MashupPlatform.wiring, 'hasInputConnections', {
+        value: function hasInputConnections(inputName) {
+            if (inputName in resource.inputs) {
+                return resource.inputs[inputName].inputs.length > 0;
+            } else {
+                var exception_msg = platform.interpolate('"%(endpoint)s" is not a valid input endpoint', {endpoint: inputName}, true);
+                throw new MashupPlatform.wiring.EndpointDoesNotExistError(exception_msg);
+            }
+        }
+    });
+    Object.defineProperty(window.MashupPlatform.wiring, 'hasOutputConnections', {
+        value: function hasOutputConnections(outputName) {
+            if (outputName in resource.outputs) {
+                return resource.outputs[outputName].outputList.length > 0;
+            } else {
+                var exception_msg = platform.interpolate('"%(endpoint)s" is not a valid output endpoint', {endpoint: outputName}, true);
+                throw new MashupPlatform.wiring.EndpointDoesNotExistError(exception_msg);
             }
         }
     });
     Object.defineProperty(window.MashupPlatform.wiring, 'getReachableEndpoints', {
         value: function getReachableEndpoints(outputName) {
             if (outputName in resource.outputs) {
-                return resource.outputs[outputName].getFinalSlots();
+                return resource.outputs[outputName].getReachableEndpoints();
             } else {
                 var exception_msg = platform.interpolate('"%(endpoint)s" is not a valid output endpoint', {endpoint: outputName}, true);
-                var log_msg = platform.interpolate('Error calling MashupPlatform.wiring.getReachableEndpoints: %(msg)s', {msg: exception_msg}, true);
-                resource.logManager.log(log_msg);
-                throw new MashupPlatform.wiring.EndpointError(exception_msg);
+                throw new MashupPlatform.wiring.EndpointDoesNotExistError(exception_msg);
             }
         }
     });
-    Object.defineProperty(window.MashupPlatform.wiring, 'EndpointError', {
-        value: platform.Wirecloud.wiring.EndpointError
-    });
+    Object.defineProperty(window.MashupPlatform.wiring, 'EndpointDoesNotExistError', {value: Wirecloud.wiring.EndpointDoesNotExistError});
+    Object.defineProperty(window.MashupPlatform.wiring, 'EndpointTypeError', {value: Wirecloud.wiring.EndpointTypeError});
+    Object.defineProperty(window.MashupPlatform.wiring, 'EndpointValueError', {value: Wirecloud.wiring.EndpointValueError});
     Object.preventExtensions(window.MashupPlatform.wiring);
 
+
+    // General error handler
+    window.onerror = function (message, url, line, column, error) {
+        var details;
+
+        if (error) {
+            details = platform.gettext("<ul><li><b>File:</b> <t:file/></li><li><b>Line: </b><t:line/></li></ul><p>See the <a href=\"http://webmasters.stackexchange.com/questions/8525/how-to-open-the-javascript-console-in-different-browsers\" target=\"_blank\">browser console</a> for more details</p>");
+            details = guibuilder.parse(guibuilder.DEFAULT_OPENING + details + guibuilder.DEFAULT_CLOSING, {file: url.replace(resource.meta.base_url, ''), line: line});
+            resource.logManager.log(message, {details: details, console: false});
+        }
+    };
 })();
