@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2014 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2014-2017 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,6 +19,9 @@
  *
  */
 
+/* globals Wirecloud */
+
+
 (function () {
 
     "use strict";
@@ -26,23 +29,26 @@
     /**
      * @author aarranz
      */
-    var PersistentVariableDef = function PersistentVariableDef(name, type, options) {
+    var PersistentVariableDef = function PersistentVariableDef(options) {
+
+        if (options == null || typeof options !== "object") {
+            throw new TypeError('Invalid options parameter');
+        }
 
         if (options.default != null && typeof options.default !== "string") {
             throw new TypeError('Invalid default option');
         }
 
-        // the value option is only used on the server side
-        if ('value' in options) {
-            delete options.value;
-        }
-
-        Object.defineProperty(this, 'name', {value: name});
-        Object.defineProperty(this, 'type', {value: type});
-        Object.defineProperty(this, 'label', {value: options.label});
-        Object.defineProperty(this, 'description', {value: options.description});
-        Object.defineProperty(this, 'options', {value: options});
-        Object.defineProperty(this, 'default', {value: options.default});
+        Object.defineProperties(this, {
+            name: {value: options.name},
+            type: {value: options.type},
+            label: {value: options.label},
+            description: {value: options.description},
+            multiuser: {value: options.multiuser},
+            secure: {value: options.secure},
+            options: {value: options},
+            default: {value: options.default}
+        });
     };
 
     Wirecloud.PersistentVariableDef = PersistentVariableDef;
