@@ -26,11 +26,8 @@ import rdflib
 import json
 
 from django.contrib.auth.models import AnonymousUser, User
-try:
-    from django.db.migrations.exceptions import IrreversibleError
-except:
-    # Django 1.8 doesn't support IrreversibleError
-    IrreversibleError = Exception
+from django.db.migrations.exceptions import IrreversibleError
+from django.test import TransactionTestCase
 from mock import Mock, create_autospec
 import six
 from unittest import TestCase
@@ -42,7 +39,6 @@ from wirecloud.platform.models import IWidget, Tab, UserWorkspace, Workspace
 from wirecloud.platform.preferences.views import update_workspace_preferences
 from wirecloud.platform.workspace.mashupTemplateGenerator import build_json_template_from_workspace, build_xml_template_from_workspace, build_rdf_template_from_workspace
 from wirecloud.platform.workspace.mashupTemplateParser import buildWorkspaceFromTemplate, fillWorkspaceUsingTemplate
-from wirecloud.platform.workspace.searchers import WorkspaceSearcher
 from wirecloud.platform.workspace.utils import get_global_workspace_data, encrypt_value
 from wirecloud.platform.workspace.views import createEmptyWorkspace
 from wirecloud.platform.migration_utils import multiuser_variables_structure_forwards, multiuser_variables_structure_backwards
@@ -219,10 +215,12 @@ def check_secure_preferences(self, workspace, user):
     self.assertEqual(data["wiring"]["operators"]["2"]["preferences"]["pref_secure"]["value"], "********")
 
 
-class WorkspaceTestCase(WirecloudTestCase):
+class WorkspaceTestCase(WirecloudTestCase, TransactionTestCase):
 
     fixtures = ('test_data',)
     tags = ('wirecloud-noselenium', 'wirecloud-workspace')
+    populate = False
+    use_search_indexes = False
 
     def setUp(self):
         super(WorkspaceTestCase, self).setUp()
@@ -296,26 +294,13 @@ class WorkspaceTestCase(WirecloudTestCase):
         self.assertEqual(data['owner'], self.user.username)
         self.assertFalse(data['shared'], False)
 
-    def test_build_search_fields(self):
 
-        searcher = WorkspaceSearcher()
-        workspace = create_autospec(Workspace())
-        fields = searcher.build_compatible_fields(workspace)
-        self.assertEqual(set(fields.keys()), {'id', 'owner', 'name', 'description', 'lastmodified', 'longdescription', 'public', 'users', 'groups', 'shared', 'searchable', 'title'})
-
-    def test_build_search_fields_no_last_modified(self):
-
-        searcher = WorkspaceSearcher()
-        workspace = create_autospec(Workspace())
-        workspace.last_modified = None
-        fields = searcher.build_compatible_fields(workspace)
-        self.assertEqual(set(fields.keys()), {'id', 'owner', 'name', 'description', 'lastmodified', 'longdescription', 'public', 'users', 'groups', 'shared', 'searchable', 'title'})
-
-
-class WorkspaceCacheTestCase(WirecloudTestCase):
+class WorkspaceCacheTestCase(WirecloudTestCase, TransactionTestCase):
 
     fixtures = ('test_data',)
     tags = ('wirecloud-workspace', 'wirecloud-noselenium')
+    populate = False
+    use_search_indexes = False
 
     def setUp(self):
         super(WorkspaceCacheTestCase, self).setUp()
@@ -398,7 +383,7 @@ class WorkspaceCacheTestCase(WirecloudTestCase):
         self.assertEqual(len(iwidget_list), 1)
 
 
-class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
+class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase, TransactionTestCase):
 
     WIRE = rdflib.Namespace('http://wirecloud.conwet.fi.upm.es/ns/widget#')
     WIRE_M = rdflib.Namespace('http://wirecloud.conwet.fi.upm.es/ns/mashup#')
@@ -410,6 +395,8 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
 
     fixtures = ('test_data',)
     tags = ('wirecloud-workspace', 'wirecloud-template', 'wirecloud-workspace-write', 'wirecloud-noselenium')
+    populate = False
+    use_search_indexes = False
 
     @classmethod
     def setUpClass(cls):
@@ -1156,12 +1143,14 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
         self.assertNotIn("public", template.get("preferences", {}))
 
 
-class ParameterizedWorkspaceParseTestCase(WirecloudTestCase):
+class ParameterizedWorkspaceParseTestCase(WirecloudTestCase, TransactionTestCase):
 
     fixtures = ('selenium_test_data', 'user_with_workspaces')
     tags = ('wirecloud-workspace', 'wirecloud-template', 'wirecloud-workspace-parse', 'wirecloud-noselenium')
 
     base_resources = ('Wirecloud_TestOperator_1.0.zip', 'Wirecloud_Test_1.0.wgt')
+    populate = False
+    use_search_indexes = False
 
     def setUp(self):
 
